@@ -2,6 +2,7 @@
 #include "RefSource.h"
 #include "Reference.h"
 #include "Exception.h"
+#include "DelegatedRef.h"
 #include "Core/Array.h"
 #include "Core/StrBuf.h"
 #include "Core/Str.h"
@@ -15,23 +16,30 @@ namespace code {
 	RefSource::RefSource(Content *content) : cont(content) {
 		refs = new (this) WeakSet<Reference>();
 		if (cont)
-			atomicWrite(cont->owner, this);
+			atomicWrite(cont->cOwner, this);
 	}
 
 	void RefSource::set(Content *to) {
 		if (cont != to) {
-			assert(to->owner == null, L"Multiple owners of a single Content object.");
+			assert(to->cOwner == null, L"Multiple owners of a single Content object.");
 
 			if (cont)
-				atomicWrite(cont->owner, (RefSource *)null);
+				atomicWrite(cont->cOwner, (RefSource *)null);
 			if (to)
-				atomicWrite(to->owner, this);
+				atomicWrite(to->cOwner, this);
 			cont = to;
 		}
 
 		update();
 	}
 
+	void RefSource::clear() {
+		if (cont)
+			atomicWrite(cont->cOwner, (RefSource *)null);
+		cont = null;
+		update();
+	}
+
 	void RefSource::update() {
 		const void *addr = address();
 		WeakSet<Reference>::Iter i = refs->iter();
@@ -39,10 +47,32 @@ namespace code {
 			ref->moved(addr);
 	}
 
+	RefSource *RefSource::findActual() {
+		if (cont)
+			if (RefSource *r = cont->stolenBy())
+				return r->findActual();
+		return this;
+	}
+
 	void RefSource::setPtr(const void *to) {
 		set(new (this) StaticContent(to));
 	}
 
+	void RefSource::steal(RefSource *from) {
+		const void *addr = address();
+		WeakSet<Reference>::Iter i = from->refs->iter();
+		while (Reference *ref = i.next()) {
+			refs->put(ref);
+			ref->to = this;
+			ref->moved(addr);
+		}
+
+		from->refs->clear();
+
+		// Keep 'from' updated while it is alive. Otherwise any 'Ref' instances will not be updated.
+		from->set(new (this) StolenContent(this));
+	}
+
 	void RefSource::toS(StrBuf *to) const {
 		*to << title();
 	}
@@ -56,6 +86,10 @@ namespace code {
 		name = new (this) Str(title);
 	}
 
+	StrRefSource::StrRefSource(const wchar *title, Content *content) : RefSource(content) {
+		name = new (this) Str(title);
+	}
+
 	StrRefSource::StrRefSource(Str *title) : RefSource(), name(title) {}
 
 	StrRefSource::StrRefSource(Str *title, Content *content) : RefSource(content), name(title) {}
