@@ -513,7 +513,7 @@ namespace storm {
 				throw new (this) SyntaxError(pos, msg);
 			}
 
-			if (v->initializer) {
+			if (v->initializer()) {
 				// If an initializer was specified, use that.
 				initVarInitializer(s, v);
 			} else if (t.isPrimitive()) {
@@ -553,7 +553,7 @@ namespace storm {
 		void InitBlock::initVarInitializer(CodeGen *s, MemberVar *v) {
 			using namespace code;
 
-			assert(v->initializer);
+			assert(v->initializer());
 
 			code::Var dest = thisVar->var.v;
 			code::Var resultPtr = s->l->createVar(s->block, Size::sPtr);
@@ -564,7 +564,7 @@ namespace storm {
 			*s->l << mov(resultPtr, ptrA);
 
 			// Call the function.
-			v->initializer->autoCallRef(s, new (this) Array<code::Operand>(), resultPtr);
+			v->initializer()->autoCallRef(s, new (this) Array<code::Operand>(), resultPtr);
 		}
 
 		void InitBlock::initVar(CodeGen *s, MemberVar *v, Initializer *to) {
