@@ -17,10 +17,10 @@ namespace storm {
 			virtual ScopeLookup *STORM_FN clone() const;
 
 			// Add included package, taking exports into account.
-			void STORM_FN addInclude(Package *p);
+			Bool STORM_FN addInclude(Package *p);
 
 			// Add included package, possibly ignoring exports.
-			void STORM_FN addInclude(Package *p, Bool useExports);
+			Bool STORM_FN addInclude(Package *p, Bool useExports);
 
 			// Get all included packages.
 			Array<Package *> *STORM_FN includes() const;
