@@ -143,7 +143,7 @@ namespace storm {
 				throw new (found) SyntaxError(pos, S("Manual invocation of destructors is not possible."));
 
 			if (Function *f = as<Function>(found))
-				return new (found) FnCall(pos, scope, f, params, useLookup);
+				return new (found) FnCall(pos, scope, f, params, useLookup, firstImplicit);
 
 			if (LocalVar *v = as<LocalVar>(found))
 				return new (found) LocalVarAccess(pos, v);
