@@ -18,9 +18,6 @@ namespace storm {
 			virtual FnBody *STORM_FN createBody();
 
 		private:
-			// Location.
-			SrcPos pos;
-
 			// Scope.
 			Scope scope;
 
