@@ -48,6 +48,14 @@ namespace storm {
 		}
 	}
 
+	static void enumUnion(InlineParams p) {
+		if (p.result->needed()) {
+			Operand result = p.result->location(p.state);
+			*p.state->l << mov(result, p.param(0));
+			*p.state->l << band(result, p.param(1));
+		}
+	}
+
 	static void enumGet(InlineParams p) {
 		if (p.result->needed()) {
 			if (!p.result->suggest(p.state, p.param(0)))
@@ -104,6 +112,7 @@ namespace storm {
 			add(inlinedFunction(engine, Value(this), S("-"), vv, fnPtr(engine, &enumSub))->makePure());
 			add(inlinedFunction(engine, b, S("&"), vv, fnPtr(engine, &enumOverlaps))->makePure());
 			add(inlinedFunction(engine, b, S("has"), vv, fnPtr(engine, &enumOverlaps))->makePure());
+			add(inlinedFunction(engine, Value(this), S("union"), vv, fnPtr(engine, &enumUnion))->makePure());
 		}
 
 		add(inlinedFunction(engine, nat, S("v"), v, fnPtr(engine, &enumGet))->makePure());
