@@ -25,6 +25,9 @@ namespace storm {
 
 		// To string.
 		void STORM_FN toS(StrBuf *to) const;
+
+		// Can replace another entity?
+		virtual MAYBE(Str *) STORM_FN canReplace(Named *old, ReplaceContext *ctx);
 	};
 
 
