@@ -40,14 +40,20 @@ namespace storm {
 	 */
 
 	MemberVar::MemberVar(Str *name, Value type, Type *member) : Variable(SrcPos(), name, type, member) {
+		ref = new (this) NamedOffsetSource(this, Char('o'));
 		hasLayout = false;
 	}
 
 	MemberVar::MemberVar(SrcPos pos, Str *name, Value type, Type *member) : Variable(pos, name, type, member) {
+		ref = new (this) NamedOffsetSource(this, Char('o'));
 		hasLayout = false;
 	}
 
-	Offset MemberVar::offset() const {
+	code::OffsetRef MemberVar::offset() const {
+		return code::OffsetRef(ref);
+	}
+
+	Offset MemberVar::rawOffset() const {
 		if (!hasLayout) {
 			owner()->doLayout();
 		}
@@ -57,6 +63,7 @@ namespace storm {
 	void MemberVar::setOffset(Offset to) {
 		hasLayout = true;
 		off = to;
+		ref->set(to);
 	}
 
 	Type *MemberVar::owner() const {
@@ -64,6 +71,49 @@ namespace storm {
 		return params->at(0).type;
 	}
 
+	void MemberVar::initializer(MAYBE(Function *) f) {
+		initFn = f;
+		f->make(fnStatic);
+		makeChild(f);
+	}
+
+	void MemberVar::discardSource() {
+		if (initFn)
+			initFn->discardSource();
+	}
+
+	MAYBE(Str *) MemberVar::canReplace(Named *old, ReplaceContext *ctx) {
+		MemberVar *o = as<MemberVar>(old);
+		if (!o)
+			return new (this) Str(S("Cannot replace a non-member variable with something else."));
+
+		if (!ctx->normalize(type).mayStore(ctx->normalize(type)))
+			return new (this) Str(S("Can not change the type of a member variable to something non-compatible."));
+
+		if (initFn && o->initFn) {
+			if (Str *error = initFn->canReplace(o->initFn, ctx))
+				return error;
+		} else if (!initFn && o->initFn) {
+			return new (this) Str(S("Can not remove an initializer from a variable."));
+		}
+
+		return null;
+	}
+
+	void MemberVar::doReplace(Named *old, ReplaceTasks *tasks, ReplaceContext *context) {
+		MemberVar *o = (MemberVar *)old;
+		hasLayout = o->hasLayout;
+		off = o->off;
+		ref->set(off);
+		ref->steal(o->ref);
+
+		if (initFn && o->initFn)
+			initFn->replace(o->initFn, tasks, context);
+		initFn = o->initFn;
+		if (initFn)
+			makeChild(initFn);
+	}
+
 
 	/**
 	 * Global variable.
@@ -138,9 +188,9 @@ namespace storm {
 			call.callRaw(callFn->ref().address(), true, null, outPtr);
 		} else {
 			// Call on the specified thread.
-			os::FutureSema<os::Sema> future;
+			os::FutureBase future;
 			os::UThread::spawnRaw(callFn->ref().address(), true, null, call, future, outPtr, &initOn);
-			future.result();
+			future.result(&updateFutureExceptions, null);
 		}
 
 		// Mark ourselves as initialized.
@@ -172,10 +222,10 @@ namespace storm {
 			const os::Thread &t = TObject::associatedThread()->thread();
 			if (t != os::Thread::current()) {
 				GlobalVar *me = this;
-				os::Future<void, Semaphore> f;
+				os::Future<void> f(os::FutureMode::exclusive);
 				os::FnCall<void, 1> p = os::fnCall().add(me);
 				os::UThread::spawn(address(&GlobalVar::create), true, p, f, &t);
-				f.result();
+				f.result(&updateFutureExceptions, null);
 			} else {
 				create();
 			}
