@@ -83,7 +83,8 @@ namespace storm {
 		// Read the entire file without any conversions of line endings (still ignores any BOM).
 		Str *STORM_FN readAllRaw();
 
-		// Does the file contain any more data?
+		// Does the file contain any more data? Note: if a timeout is reached in the underlying
+		// stream, 'more' will return false until a future call of `peek` or `read`.
 		Bool STORM_FN more();
 
 		// Close the underlying stream.
@@ -120,6 +121,9 @@ namespace storm {
 	// Create a text reader that reads data from a string. Utilizes `StrInput`.
 	TextInput *STORM_FN readStr(Str *from);
 
+	// Read the text from a file into a string. Equivalent to calling `readText(file).readAll()`.
+	Str *STORM_FN readAllText(IStream *stream);
+
 	// Read the text from a file into a string. Equivalent to calling `readText(file).readAll()`.
 	Str *STORM_FN readAllText(Url *file);
 
