@@ -117,13 +117,14 @@ namespace gui {
 	}
 
 	void CheckButton::checked(Bool v) {
-		if (isChecked != v) {
-			isChecked = v;
-			changed(v);
-		}
-
 		if (created()) {
+			isChecked = v;
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(handle().widget()), isChecked);
+		} else {
+			if (isChecked != v) {
+				isChecked = v;
+				changed(v);
+			}
 		}
 	}
 
