@@ -16,12 +16,17 @@ namespace gui {
 	}
 
 	MsgResult noResult() {
-		MsgResult r = { false, 0 };
+		MsgResult r = { false, false, 0 };
+		return r;
+	}
+
+	MsgResult noResultNotify() {
+		MsgResult r = { false, true, 0 };
 		return r;
 	}
 
 	MsgResult msgResult(LRESULT code) {
-		MsgResult r = { true, code };
+		MsgResult r = { true, false, code };
 		return r;
 	}
 
