@@ -490,9 +490,19 @@ int stormMain(int argc, const wchar_t *argv[]) {
 
 #ifdef WINDOWS
 
+const UINT targetCP = 65001;
+
 int _tmain(int argc, const wchar *argv[]) {
 	int result = 0;
 
+	// Set output codepage to UTF-8
+	UINT inputCP = GetConsoleCP();
+	UINT outputCP = GetConsoleOutputCP();
+	if (inputCP != 0 && inputCP != targetCP)
+		SetConsoleCP(targetCP);
+	if (outputCP != 0 && outputCP != targetCP)
+		SetConsoleOutputCP(targetCP);
+
 	try {
 		result = stormMain(argc, argv);
 	} catch (const ::Exception &e) {
@@ -513,6 +523,12 @@ int _tmain(int argc, const wchar *argv[]) {
 		}
 	}
 
+	// Restore codepage:
+	if (inputCP != 0 && inputCP != targetCP)
+		SetConsoleCP(inputCP);
+	if (outputCP != 0 && outputCP != targetCP)
+		SetConsoleOutputCP(outputCP);
+
 	return result;
 }
 
