@@ -34,10 +34,10 @@ namespace sql {
 
 	// Create an instance of the MYSQL object. This can then be used to access the entire
 	// MySQL/MariaDB API. Loads the mariadb library as needed.
-	MYSQL *createDriver(Engine &e);
+	MYSQL *createMariaDBDriver(Engine &e);
 
 	// Destroy an instance of a driver. This allows the implementation to reference count and
 	// determine when/if to unload the mysql library.
-	void destroyDriver(MYSQL *driver);
+	void destroyMariaDBDriver(MYSQL *driver);
 
 }
