@@ -6,12 +6,17 @@
 static Engine *engineObj = null;
 static void *stackBase = null;
 
+static Url *createRoot(Engine &e, void *param) {
+	(void)param;
+	Url *root = executableUrl(e)->parent();
+	return root->pushDir(new (e) Str(S("root")));
+}
+
 Engine &gEngine() {
 	if (!engineObj) {
 		PLN(L"==> Starting compiler...");
 		Moment start;
-		Path root = Path::executable() + Path(L"../root/");
-		engineObj = new Engine(root, Engine::reuseMain, stackBase);
+		engineObj = new Engine(&createRoot, null, Engine::reuseMain, stackBase);
 		PLN(L"==> Compiler boot: " << (Moment() - start));
 	}
 	return *engineObj;
