@@ -200,6 +200,14 @@
 #if defined(GCC) && defined(ARM64)
 // ARM64 does not need to specify a calling convention. There is a single standard convention!
 #define CODECALL
+
+// Detect pointer authentication and branch target identification.
+#if __ARM_FEATURE_PAC_DEFAULT
+#define ARM_USE_PAC
+#endif
+#if __ARM_FEATURE_BTI_DEFAULT
+#define ARM_USE_BTI
+#endif
 #endif
 
 // Make sure it is defined.
